# Plorts - Niceish python plots

[![Documentation Status](https://readthedocs.org/projects/plorts/badge/?version=latest)](https://plorts.readthedocs.io/en/latest/?badge=latest)


Like seaborn but with less stuff and also it starts faster

```
$ pip install plorts
```

## Examples

For the code to make these examples, see [Sample.ipynb](https://github.com/brucespang/plorts/blob/master/Sample.ipynb)

![](output/line-plot.png)
![](output/scatter-plot.png)
![](output/stack-plot.png)
![](output/boxplot.png)
![](output/histogram.png)
![](output/cdf.png)
![](output/pdf.png)
